@@ -359,10 +359,12 @@ def make_release(release_tag,git_url,github_user,github_pass):
     print("Making release ...")
     
     
+    script_dir = os.path.dirname(os.path.realpath(__file__))
+
     if platform.system() == 'Linux':
-        driver_path_firefox = 'resources/geckodriver'
+        driver_path_firefox = os.path.join(script_dir,'resources/geckodriver')
     elif platform.system() == 'Windows':
-        driver_path_firefox = 'resources/geckodriver.exe'
+        driver_path_firefox = os.path.join(script_dir,'resources/geckodriver.exe')
 
 
     options = Options()
